Special characters — Pootle 2.5.1 documentation

# Special characters

Pootle can display clickable characters to help people insert characters which might be difficult to type. For many languages using the Latin alphabet with diacritics, this helps a lot, especially where keyboard layouts are not always common.

This page allows people to specify which characters might be useful for translators. This does not solve the input needs for all languages, but has been a very useful help for many languages, especially in translate@thons.

For people using non-Latin scripts, consider if it will be useful to perhaps include things that can’t be easily typed by translators in your language. We will probably need to limit the number of characters, but hopefully we can find a reasonable compromise that will help many people.

If you edit this page, please ensure that you use a browser that supports UTF-8 encoding so that the existing text is kept intact. Note that you might not be able to see all the characters on this page if you do not have the appropriate fonts installed. Please take care not to edit something inadvertently.

## The characters

Afrikaans
  áéíóúý äëïöü âêîôû è
Northern Sotho
  šŠ
Tswana
  šŠ êô
Venda

  ḓḒḽḼṊṋṰṱ Ṅṅ

  old orthography: áéíóú a̗e̗i̗o̗u̗

Vietnamese (vi)

  àảãáạăằẳẵắặâầẩẫấậèẻẽéẹêềểễếệìỉĩíịòỏõóọôồổỗốộơờởỡớợùủũúụưừửữứựỳỷỹýỵđ₫«» ÀẢÃÁẠĂẰẲẴẮẶÂẦẨẪẤẬÈẺẼÉẸÊỀỂỄẾỆÌỈĨÍỊÒỎÕÓỌÔỒỔỖỐỘƠỜỞỠỚỢÙỦŨÚỤƯỪỬỮỨỰỲỶỸÝỴĐ

  You could prioritize by excluding the characters covered by the Latin-1 codeset, which are available via most standard keyboards.

  Since Vietnamese is mostly composed of accented vowels as above, the priority should be to help users acquire the appropriate input systems and keyboard layouts. Relying on clicking each character from a palette would slow down translation severely. However, it would make translation possible in the short term for those who can’t yet input our language, or for those accessing computers which for some reason won’t use the correct input software.